Module input

Module input 

Input handling.

Currently provides keyboard support with is_key_pressed, is_key_down, get_pressed_keys and get_held_keys

Enums

KeyCode
A physical key on the keyboard.

Functions

clear
Clears all keys pressed this frame.
get_held_keys
Get a list of keys currently being held down.
get_pressed_keys
Get a list of keys pressed within this frame.
is_key_down
Is this key being held down?
is_key_pressed
Was this key pressed this frame?
press_key
Simulate pressing a key.
release_key
Simulate releasing a key.