Input handling.
Currently provides keyboard support with is_key_pressed, is_key_down,
get_pressed_keys and get_held_keys
Enums
- KeyCode
- A physical key on the keyboard.
Functions
- clear
- Clears all keys pressed this frame.
- get_
held_ keys - Get a list of keys currently being held down.
- get_
pressed_ keys - Get a list of keys pressed within this frame.
- is_
key_ down - Is this key being held down?
- is_
key_ pressed - Was this key pressed this frame?
- press_
key - Simulate pressing a key.
- release_
key - Simulate releasing a key.